<!-- # Quantum enhanced Markov Chain Monte Carlo Simulator Documentation -->


```{include} ../../README.md
:relative-images:
```

```{toctree}
:maxdepth: 2
:caption: Getting Started

getting-started
energy-model
coarse-graining
```

```{toctree}
:maxdepth: 2
:caption: Usage

example
```

```{toctree}
:maxdepth: 2
:caption: Package API Docs

api/index
```

```{toctree}
:maxdepth: 2
:caption: Development

github
license
authors
```